ChangeLog
=========

0.1.6
-----

* Added a link to the parent directory.

0.1.5
-----

* Replace os.path.relpath with custom code, because it absent in Python2.5.
* Add 'parent' context variable.

0.1.4
-----

* Directory path normalized for 'title' context variable, to remove /./ component.
* UTF-8 charset in example template.

0.1.3
-----

* Sorted app list.
* Additional context variables like app, cwd, leaf, rel_path and full path in templates.

0.1.2
-----

* Return 404 for ignored file.

0.1.1
-----

* Security hole, allowing to read any file, was fixed.
* Return 404 for non existent files.

0.1.0
-----

* First version with simple templates and pygments support.
